libyang REFACTOR minor improvements
diff --git a/src/plugins_internal.h b/src/plugins_internal.h
index f624624..59adacf 100644
--- a/src/plugins_internal.h
+++ b/src/plugins_internal.h
@@ -48,12 +48,12 @@
  *
  * Covers both the types and extensions plugins.
  *
  * @param[in] builtin_plugins_only Whether to load only built-in YANG plugin types and extensions.
  * @return LY_SUCCESS in case of success
  * @return LY_EINT in case of internal error
  * @return LY_EMEM in case of memory allocation failure.
  */
-LY_ERR lyplg_init(ly_bool builtin_plugins_only);
+LY_ERR lyplg_init(ly_bool builtin_type_plugins_only);
 
 /**
  * @brief Remove (unload) all the plugins currently available.
@@ -48,12 +48,12 @@
  * Covers both the types and extensions plugins.
  *
- * @param[in] builtin_plugins_only Whether to load only built-in YANG plugin types and extensions.
+ * @param[in] builtin_type_plugins_only Whether to load only built-in YANG type plugins and no included extension plugins.
  * @return LY_SUCCESS in case of success
  * @return LY_EINT in case of internal error